Package: hypeR
Title: An R Package For Geneset Enrichment Workflows
Version: 2.10.0
Authors@R: c(person(given="Anthony", family="Federico", email="anfed@bu.edu", 
             role=c("aut")),
             person(given="Andrew", family="Chen", email="andrewdr@bu.edu", 
             role=c("aut", "cre")),
             person(given="Stefano", family="Monti", email="smonti@bu.edu", 
             role=c("aut")))
Description: An R Package for Geneset Enrichment Workflows.
Depends: R (>= 3.6.0)
License: GPL-3 + file LICENSE
URL: https://github.com/montilab/hypeR
Encoding: UTF-8
RoxygenNote: 7.3.1
Imports: ggplot2, ggforce, R6, magrittr, dplyr, purrr, stats, stringr,
        scales, rlang, httr, openxlsx, htmltools, reshape2, reactable,
        msigdbr, kableExtra, rmarkdown, igraph, visNetwork, shiny,
        BiocStyle
Suggests: tidyverse, devtools, testthat, knitr
biocViews: GeneSetEnrichment, Annotation, Pathways
VignetteBuilder: knitr
BugReports: https://github.com/montilab/hypeR/issues
git_url: https://git.bioconductor.org/packages/hypeR
git_branch: RELEASE_3_23
git_last_commit: 6ec1e80
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-29
NeedsCompilation: no
Packaged: 2026-04-29 22:24:10 UTC; biocbuild
Author: Anthony Federico [aut],
  Andrew Chen [aut, cre],
  Stefano Monti [aut]
Maintainer: Andrew Chen <andrewdr@bu.edu>
