#' Differential Expression
#'
#' A differential expression table
#' 
#' @format A data frame
#' 
"limma"

#' Co-expression Modules
#'
#' A list of co-expression modules
#' 
#' @format A nested list of character vectors
#' 
"wgcna"
