---
title: "Installation"
vignette: >
  %\VignetteIndexEntry{Installation}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

We recommend the latest version of R (\>= 4.0.0) but **hypeR** currently requires R (\>= 3.6.0) to be installed directly from Github or Bioconductor. To install with R (\>= 3.5.0) see below. Use with R (\< 3.5.0) is not recommended.

Install the development version of the package from Github.
```{r, eval=FALSE}
devtools::install_github("montilab/hypeR")
```

Or install the development version of the package from Bioconductor.
```{r, eval=FALSE}
BiocManager::install("montilab/hypeR", version="devel")
```

Or install with Conda.
```{r eval=FALSE}
conda create --name hyper
source activate hyper
conda install -c r r-devtools
R
library(devtools)
devtools::install_github("montilab/hypeR")
```

Or install with previous versions of R.
```{r eval=FALSE}
git clone https://github.com/montilab/hypeR
nano hypeR/DESCRIPTION
# Change Line 8
# Depends: R (>= 3.6.0) -> Depends: R (>= 3.5.0)
R
install.packages("path/to/hypeR", repos=NULL, type="source")
```

Load the package into an R session.
```{r, eval=FALSE}
library(hypeR)
```
