=pod

=head1 NAME

Hyper::Manual - Manual for the Hyper Framework

=head1 SECTIONS

 L<Manual::Control::Setup|Manual::Control::Setup> - how to create new controls

=head1 AUTHOR

Martin Kutter <kutterma@users.sourceforge.net>

=head1 COPYING

=head1 Repository information

 $ID: $

 $LastChangedDate: $
 $LastChangedRevision: $
 $LastChangedBy: $

 $HeadURL: $

=cut
