=head1 NAME

Hyper::Manual::Usecase::Howto - how to implement a usecase with the Hyper Framework

=head1 STEPS

=head2 Create etc/Hyper/Control/Flow/FUsecase.ini

=over

=item * Generate the interface for this usecase

 generate-interface.pl -s Service -u Usecase

This script will make a module like

 lib/Hyper/Interface/$Service/I$Usecase.pm

See the embedded pod of this file for a list of available interface methods.

=item * Write down all steps from use case design as [Step $NAME] sections

Transitions are written as

 [Step $NAME $NEXT_NAME]
 condition=...

The condition is optional.

=item * Write down all required controls for the steps as [Control $NAME]

You may need new controls - in this case you have to create
them.

See <Hyper::Manual::Control::Howto>

=back

=head2 Run generate-flow.pl on your usecase

=cut

