% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ggempty.R
\name{ggempty}
\alias{ggempty}
\title{An empty ggplot}
\usage{
ggempty()
}
\value{
A ggplot object
}
\description{
An empty ggplot
}
