% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/db_msig.R
\name{msigdb_info}
\alias{msigdb_info}
\title{Print msigdb gsets information}
\usage{
msigdb_info()
}
\description{
Print msigdb gsets information
}
\examples{
msigdb_info()

}
