% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{wgcna}
\alias{wgcna}
\title{Co-expression Modules}
\format{
A nested list of character vectors
}
\usage{
wgcna
}
\description{
A list of co-expression modules
}
\keyword{datasets}
