% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{limma}
\alias{limma}
\title{Differential Expression}
\format{
A data frame
}
\usage{
limma
}
\description{
A differential expression table
}
\keyword{datasets}
