% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/db_hyper.R
\name{.hyperdb_url}
\alias{.hyperdb_url}
\title{Get base url for hyperdb}
\usage{
.hyperdb_url(api = FALSE)
}
\value{
A base url
}
\description{
Get base url for hyperdb
}
\keyword{internal}
